@@ -63,23 +63,8 @@ class Webhook(Model):
 class TaskData(Model):
     """ objects within taskdata list in Manifest """
     task_key = UUIDType(required=True)
-    datapoint_uri = URLType()
+    datapoint_uri = URLType(required=True, min_length=10)
     datapoint_hash = StringType(required=True, min_length=10)
-    datapoint_text = DictType(StringType)
-    is_text_question = BooleanType()
-
-    def validate_datapoint_text(self, data, value):
-        if data.get('is_text_question') and not value:
-            raise ValidationError("datapoint_text is missing.")
-        return value
-
-    def validate_datapoint_uri(self, data, value):
-        if not data.get('is_text_question'):
-            if not value:
-                raise ValidationError("datapoint_uri is missing.")
-            if len(value) < 10:
-                raise ValidationError("datapoint_uri length is less than 10")
-        return value
 
 
 class RequestConfig(Model):
@@ -94,7 +79,7 @@ class RequestConfig(Model):
     minimum_selection_area_per_shape = IntType()
     multiple_choice_max_choices = IntType(default=1)
     multiple_choice_min_choices = IntType(default=1)
-
+    overlap_threshold = FloatType(required=False)
 
 class InternalConfig(Model):
     """ discarded from incoming manifests """
@@ -183,6 +168,7 @@ class Manifest(Model):
     job_id = UUIDType(default=uuid.uuid4)
     job_total_tasks = IntType(required=True)
     network = StringType(required=False)
+    only_sign_results = BooleanType(default=False,)
 
     requester_restricted_answer_set = DictType(DictType(StringType))
 
